<?php
/*
 * 功能：GEP接口调试入口页面
 * 说明：
 * 以下代码只是为了方便商户测试而提供的样例代码，商户可以根据自己网站的需要，按照技术文档编写,不建议要使用该代码。
 */

?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>接口调试页面</title>
    <style>
        body {
            font-family: "Helvetica Neue", Helvetica, Arial, "Lucida Grande", sans-serif;
            color: #333;
            background: linear-gradient(135deg, #f8f8f8 0%, #ffffff 100%);
            margin: 0;
            padding: 0;
            min-height: 100vh;
        }
        .container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 20px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.05);
            background-color: #fff;
            border-radius: 8px;
            margin-top: 20px;
        }
        .tab-head {
            display: flex;
            justify-content: center;
            margin-bottom: 20px;
            position: sticky;
            top: 50px;
            z-index: 99;
            background-color: rgba(255, 255, 255, 0.95);
            padding: 15px 20px;
            backdrop-filter: blur(10px);
            border-bottom: 1px solid #eee;
        }
        .tab-head h2 {
            padding: 12px 30px;
            margin: 0 15px;
            cursor: pointer;
            border-radius: 25px;
            transition: all 0.3s ease;
            font-weight: 500;
            letter-spacing: 0.5px;
            background-color: transparent;
            color: #666;
        }
        .tab-head h2:hover {
            background-color: rgba(2, 170, 241, 0.1);
            color: #02aaf1;
        }
        .tab-head h2.selected {
            color: #fff;
            background-color: #02aaf1;
            box-shadow: 0 4px 6px rgba(2, 170, 241, 0.2);
        }
        .tab-content {
            display: none;
            animation: fadeIn 0.3s ease;
        }
        @keyframes fadeIn {
            0% { opacity: 0; transform: translateY(10px); }
            100% { opacity: 1; transform: translateY(0); }
        }
        .tab-content.show {
            display: block;
        }
        table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
            margin-top: 20px;
            background: #fff;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.05);
            border-radius: 8px;
            overflow: hidden;
        }
        th, td {
            padding: 12px 15px;
            border-bottom: 1px solid #eee;
            text-align: left;
        }
        th {
            background: #02aaf1;
            color: #fff;
            font-weight: 600;
            text-transform: uppercase;
            font-size: 0.9em;
            letter-spacing: 0.5px;
        }
        tr:hover {
            background-color: rgba(2, 170, 241, 0.03);
        }
        a {
            color: #02aaf1;
            text-decoration: none;
            transition: all 0.2s ease;
        }
        a:hover {
            color: #0288d1;
            text-decoration: underline;
        }
        .am-header {
            display: flex;
            justify-content: center;
            align-items: center;
            background: #1D222D;
            height: 60px;
            color: #fff;
            position: sticky;
            top: 0;
            z-index: 100;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        }
        .am-header h1 {
            font-size: 1.5em;
            font-weight: 600;
            letter-spacing: 0.5px;
        }
        .footer {
            text-align: center;
            color: #666;
            margin: 30px 0 20px;
            font-size: 0.9em;
        }
        @media (max-width: 768px) {
            .container {
                padding: 15px;
            }
            .tab-head {
                flex-wrap: wrap;
                padding: 10px;
            }
            .tab-head h2 {
                margin: 5px;
                padding: 8px 20px;
                font-size: 0.9em;
            }
            .am-header h1 {
                font-size: 1.2em;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <header class="am-header">
            <h1>接口调试页面</h1>
        </header>
        <div id="main">
            <div class="tab-head">
                <h2 id="tab1" class="selected" data-content="body1">兑换分发API</h2>
                <h2 id="tab2" data-content="body2">收款账户API</h2>
                <h2 id="tab3" data-content="body3">E付卡API</h2>
            </div>
            <div id="body1" class="tab-content show">
                <?php include 'exchange.php'; ?>
            </div>
            <div id="body2" class="tab-content">
                <?php include 'store.php'; ?>
            </div>
            <div id="body3" class="tab-content">
                <?php include 'vas.php'; ?>
            </div>
            <div class="footer">
                接口测试使用，请勿做其他用途
            </div>
        </div>
    </div>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const tabs = document.querySelectorAll('.tab-head h2');
            const contents = document.querySelectorAll('.tab-content');

            tabs.forEach((tab, index) => {
                tab.addEventListener('click', function () {
                    tabs.forEach(t => t.classList.remove('selected'));
                    contents.forEach(c => c.classList.remove('show'));

                    tab.classList.add('selected');
                    contents[index].classList.add('show');
                });
            });

            // 初始化第一个 tab 为选中状态
            tabs[0].click();
        });
    </script>
</body>
</html>