<?php
date_default_timezone_set("PRC"); // 统一时区设置

require_once 'RSAUtil.php';
require_once 'HttpUtil.php';

class GepUtil
{
    private static $config;

    public static function initConfig() {
        self::$config = require __DIR__ . '/../../config.php';
    }

    private static function getConfig($key) {
        if (self::$config === null) {
            self::initConfig();
        }
        return self::$config[$key];
    }
    private const USER_NO = '5181200731000138828';
    private const CERTIFICATE_ID = '2103031802000005106';
    private const PFX_NAME = 'key_5181200731000138828@@2103031802000005106.pfx';
    private const CER_NAME = 'key_5181200731000138828@@2103031802000005106.cer';
    private const PFX_PASS = '5181200731000138828_190684';
    private const MAIN_URL = 'https://member-test-api.gepholding.com';
    private const VERSION = '1.0.0';
    private const DATA_TYPE = 'JSON';
    private const LOG_DIR = __DIR__ . '/../log/';
    
    
    public static function log(string $message): void
    {
        $logPath = self::LOG_DIR;
        if (!is_dir($logPath)) {
            mkdir($logPath, 0777, true);
        }
        $filePath = $logPath . 'log' . date('Ymd') . '.txt';
        $logTime = date('Y-m-d H:i:s');
        file_put_contents($filePath, "[$logTime]:$message\r\n", FILE_APPEND);
    }

    public static function echoFormat(string $message): void
    {
        $logTime = date('Y-m-d H:i:s');
        echo "$logTime	: $message<br>";
    }

    public static function generateRandomString(): string
    {
        return date('YmdHis') . uniqid();
    }

    public static function sendRequest($url, $params, $fileParams = null, $hasDecryptResult)
    {
        try {
            $dataContentJson = json_encode($params);
            self::echoFormat("dataContent组装明文:" . $dataContentJson);

            $ServicesPath = dirname(dirname(__FILE__));
            $encryptedDataContent = RSAUtil::encryptByPrivateKeyFile($dataContentJson, $ServicesPath . "/file/" . self::PFX_NAME, self::PFX_PASS);
            self::echoFormat("dataContent密文:" . $encryptedDataContent);
            $postFields = [
                'version' => self::VERSION,
                'certificateId' => self::CERTIFICATE_ID,
                'userNo' => self::USER_NO,
                'dataType' => self::DATA_TYPE,
                'dataContent' => $encryptedDataContent,
            ];
            self::echoFormat("请求地址:" . self::MAIN_URL . $url);

            $additionalHeaders = [];
            // 英文code
            // $additionalHeaders[] = "Accept-Language:en-US";
            $response = HttpUtil::post(self::MAIN_URL . $url, $postFields, $fileParams, $additionalHeaders);
            self::echoFormat("响应报文:" . $response);
            if (!$hasDecryptResult) {
                return $response;
            }
            $resJson = json_decode($response, true);

            if (is_array($resJson) && $resJson["success"]) {
                $result = $resJson["result"];
                if ($hasDecryptResult) {
                    $result = RSAUtil::decryptByPublicKeyFile($result, $ServicesPath . "/file/" . self::CER_NAME);
                }
                self::echoFormat("result解密明文:" . $result);
            } else {
                self::echoFormat("错误描述errorMsg:" . $resJson["errorMsg"]);
            }

        } catch (Exception $e) {
            self::log("Error: " . $e->getMessage());
            echo "Error: " . $e->getMessage();
        }
    }

}