<?php

class HttpUtil
{
    private static $postCharset = "UTF-8";
    private static $fileCharset = "UTF-8";
    private	static $timeout = 10 ;// 超时时间

    /**
     * 发送POST请求，包括文件上传
     * @param string $url 请求的URL
     * @param array|null $postFields 请求的参数
     * @param array|null $postFileFields 上传的文件
     * @return string 响应内容
     * @throws Exception 如果发生错误
     */
    public static function post($url, $postFields = null, $postFileFields = null, $additionalHeaders = [])
    {
        if (!filter_var($url, FILTER_VALIDATE_URL)) {
            throw new \InvalidArgumentException('Invalid URL provided.');
        }
        
        if ($postFields !== null && !is_array($postFields)) {
            throw new \InvalidArgumentException('Post fields must be an array.');
        }
        
        list($postBodyString, $encodeArray, $postMultipart) = self::preparePostBody($postFields, $postFileFields, self::$postCharset);
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_FAILONERROR, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        
        //超时时间
		curl_setopt($ch, CURLOPT_TIMEOUT, self::$timeout);      

        curl_setopt($ch, CURLOPT_POST, true);
        if ($postMultipart) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, $encodeArray);
        } else {
            curl_setopt($ch, CURLOPT_POSTFIELDS, rtrim($postBodyString, "&"));
        }
        // 设置请求头
        if (!$postMultipart) {
          $additionalHeaders[] = 'Content-Type: application/x-www-form-urlencoded;charset=' . self::$postCharset;
        }
        curl_setopt($ch, CURLOPT_HTTPHEADER, $additionalHeaders);

        $response = curl_exec($ch);

        if (curl_errno($ch)) {
            $errorMessage = curl_error($ch);
            error_log("Curl error: $errorMessage");
            curl_close($ch);
            throw new \RuntimeException($errorMessage, curl_errno($ch));
        }

        $httpStatusCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        if ($httpStatusCode !== 200) {
            error_log("HTTP Error: $response with status code $httpStatusCode");
            throw new \HttpException($response, $httpStatusCode);
        }

        return $response;
    }

   /**
     * 转换字符编码
     * @param string $data 要转换的字符串
     * @param string $targetCharset 目标字符编码
     * @return string 转换后的字符串
     */
    private static function characet($data, $targetCharset)
    {
        if (!empty($data)) {
            $fileType = self::$fileCharset;
            if (strcasecmp($fileType, $targetCharset) != 0) {
                $data = mb_convert_encoding($data, $targetCharset, $fileType);
            }
        }
        return $data;
    }

    private static function preparePostFields($fields, $charset)
    {
        $preparedFields = [];
        foreach ($fields as $k => $v) {
            $preparedFields[$k] = self::characet($v, $charset);
        }
        return $preparedFields;
    }
    
    private static function preparePostBody($postFields, $postFileFields, $charset)
    {
        $postBodyString = "";
        $encodeArray = [];
        $postMultipart = false;

        if (is_array($postFields) && count($postFields) > 0) {
            $postFields = self::preparePostFields($postFields, $charset);
            foreach ($postFields as $k => $v) {
                $postBodyString .= "$k=" . urlencode($v) . "&";
                $encodeArray[$k] = $v;
            }
        }

        if (is_array($postFileFields) && count($postFileFields) > 0) {
            $postMultipart = true;
            foreach ($postFileFields as $k => $v) {
                $encodeArray[$k] = new \CURLFile($v['tmp_name'], $v['type'], $v['name']);
            }
        }

        return [$postBodyString, $encodeArray, $postMultipart];
    }
}